seaborn_extensions
==================


.. image:: https://img.shields.io/pypi/v/seaborn_extensions.svg
        :target: https://pypi.python.org/pypi/seaborn_extensions

.. image:: https://img.shields.io/travis/afrendeiro/seaborn_extensions.svg
        :target: https://travis-ci.com/afrendeiro/seaborn_extensions

.. image:: https://readthedocs.org/projects/seaborn-extensions/badge/?version=latest
        :target: https://seaborn-extensions.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


My collection of general ploting functions that I build on top of seaborn.


* Free software: GNU General Public License v3
* Documentation: https://seaborn-extensions.readthedocs.io.


Features
--------

* swarmboxenplot: Overlayed swarm- and boxen-plots with significance bars between groups.
* clustermap: The great clustermap but with easy annotation of rows and columns for numeric and categorical factors.

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
